local addonName, L = ...;

local BROADCAST_COUNTDOWN, BROADCAST_CHAT_TYPE, COUNTDOWN_TIME;

local NUMBER_TEX_COORDS_TABLE = 
{
	[0] = {0, 0.25, 0, 0.33203125};
	[1] = {0.25, 0.5, 0, 0.33203125};
	[2] = {0.5, 0.75, 0, 0.33203125};
	[3] = {0.75, 1, 0, 0.33203125};
	[4] = {0, 0.25, 0.33203125, 0.66406250};
	[5] = {0.25, 0.5, 0.33203125, 0.66406250};
	[6] = {0.5, 0.75, 0.33203125, 0.66406250};
	[7] = {0.75, 1, 0.33203125, 0.66406250};
	[8] = {0, 0.25, 0.66406250, 0.99609375};
	[9] = {0.25, 0.5, 0.66406250, 0.99609375};
}

local function OnUpdate(self, elapsed)

	if ( self.count ) then
		self.elapsed = self.elapsed + elapsed;
		
		-- Statusbar Animation:
		if ( self.countDown > 9 ) then
			self.statusBar.value = self.statusBar.value - elapsed;
			self.statusBar:SetValue(self.statusBar.value);
		else
			self.statusBar:Hide();
		end
		
		if ( self.elapsed >= 1 ) then
			self.elapsed = 0;
			self.countDown = self.countDown - 1;
			
			-- StatusBar Text and Texture Handling:
			if ( self.countDown > 9 ) then
				local minutes = math.floor(self.countDown / 60);
				local seconds = self.countDown - ( minutes * 60 );
				if ( string.len(seconds) == 1 ) then
					seconds = "0"..seconds;
				end
				self.statusBarText:SetText(minutes..":"..seconds);
				self.texture:Hide();
			elseif ( self.countDown > -1 ) then
				self.texture:Show();
				self.textureFrame:SetAlpha(0);
				self.fadeIn:Play();
				self.texture:SetTexCoord(unpack(NUMBER_TEX_COORDS_TABLE[self.countDown]));
			end
			
			-- Broadcast Message Handling:
			if ( BROADCAST_COUNTDOWN ) then
				local msg;

				if ( self.countDown == 60 or self.countDown == 45 or self.countDown == 30 or self.countDown == 15 or self.countDown == 10 or self.countDown < 6 and self.countDown > 0 ) then
					if ( self.countDown == 1 ) then
						msg = string.format(L["COUNTDOWN_BROADCAST_SINGLE_SECOND_STRING"], self.countDown);
					else
						msg = string.format(L["COUNTDOWN_BROADCAST_STRING"], self.countDown);
					end
				elseif ( self.countDown == 0 ) then
					msg = L["COUNTDOWN_BROADCAST_FINISH_STRING"];
				end
				
				if ( msg ) then
					SendChatMessage(msg ,BROADCAST_CHAT_TYPE);
				end
			end
			
			if ( self.countDown <= -1 ) then
				ArenaLiveSpectator:OnEvent("ALSPEC_COUNTDOWN_FINISHED");
				ALSpec_CountDown:Reset();
			end
		end
	
	end
end

function ALSpec_CountDown:Initialise()
	local prefix = self:GetName();
	self.texture = ALSpec_CountDownTextureFrameTexture;
	self.textureFrame = _G[prefix.."TextureFrame"];
	self.fadeIn = _G[prefix.."TextureFrameFadeIn"];
	self.statusBar = ALSpec_CountDownStatusBar;
	self.statusBarText = ALSpec_CountDownStatusBarText;
	self.elapsed = 0;
	self.countDown = 0;

	self:SetScript("OnUpdate", OnUpdate);
end

function ALSpec_CountDown:Start()

	ALSpec_CountDown:UpdateVariables();
	self.countDown = COUNTDOWN_TIME;
	self.elapsed = 1;
	self.count = true;
	
	self.statusBar.value = COUNTDOWN_TIME;
	self.statusBar.maxValue = COUNTDOWN_TIME;
	self.statusBar:SetMinMaxValues(0, COUNTDOWN_TIME);
	self.statusBar:SetValue(COUNTDOWN_TIME);
	
	local minutes = math.floor(self.countDown / 60);
	local seconds = self.countDown - ( minutes * 60 );
	if ( string.len(seconds) == 1 ) then
		seconds = "0"..seconds;
	end
	self.statusBarText:SetText(minutes..":"..seconds);
	
	if ( COUNTDOWN_TIME > 9 ) then
		self.statusBar:Show();
	end
end

function ALSpec_CountDown:Reset()
	self.count = false;
	self.countDown = 0;
	self.texture:Hide();
	self.statusBar:Hide();
end

function ALSpec_CountDown:UpdateVariables()
	BROADCAST_COUNTDOWN = ArenaLiveCore:GetDBEntry(addonName, "Countdown/Broadcast");
	BROADCAST_CHAT_TYPE = ArenaLiveCore:GetDBEntry(addonName, "Countdown/BroadcastChannel");
	COUNTDOWN_TIME = ArenaLiveCore:GetDBEntry(addonName, "Countdown/Time") + 1;
end