local addonName, L = ...;

-- Local reference to the saved variable table containing the aliases.
local aliasDB;

local NameText = ArenaLiveCore:GetHandler("NameText");
local UnitFrame = ArenaLiveCore:GetHandler("UnitFrame");
local ImportExport = ArenaLiveCore:GetHandler("ImportExport");
local function ChoosePlayer_DropDown_OnClick(dropdownbutton)
	ALSpec_OptionsNameAliasesNameEditBox:SetText(dropdownbutton.value);
	
	local availableAlias = aliasDB[dropdownbutton.value] or "";
	local dropdown = UIDROPDOWNMENU_OPEN_MENU;
	
	
	if ( availableAlias ~= "" ) then
		UIDropDownMenu_SetText(ALSpec_OptionsNameAliasesChooseAliasDropDown, dropdownbutton.value);
	else
		UIDropDownMenu_SetText(ALSpec_OptionsNameAliasesChooseAliasDropDown, "");
	end
	ALSpec_OptionsNameAliasesAliasEditBox:SetText(availableAlias);
	
	UIDropDownMenu_SetText(dropdown, dropdownbutton.value);
end

local info = {};
local function ChoosePlayer_DropDown_Refresh(dropdown)

	if ( not dropdown:IsVisible() ) then
		return;
	end
	
	local id = dropdown:GetID();
	
	ALSpec_TeamMenu:RefreshAvailablePlayers();

	local currentName = ALSpec_OptionsNameAliasesNameEditBox:GetText();
	
	
	for playerName, unit in pairs(ALSPEC_AVAILABLE_PLAYERS) do
		local _, class = UnitClass(unit);
		local colourCode;

		if ( class ) then
			colourCode = "|c"..(RAID_CLASS_COLORS[class]["colorStr"]);
		end
		
		info.text = playerName;
		info.value = playerName;
		info.func = ChoosePlayer_DropDown_OnClick;
		info.arg1 = nil;
		info.colorCode = colourCode;
		
		if ( currentName == info.value ) then
			UIDropDownMenu_SetText(dropdown, info.text);
			info.checked = true;
		else
			info.checked = nil;
		end
		
		UIDropDownMenu_AddButton(info);
	end
end

local function ChoosePlayer_DropDown_Initialise(dropdown)

	local prefix = dropdown:GetName();
	
	local title = _G[prefix.."Title"];
	
	-- Set dropdown title
	title:SetText(L["NAME_ALIAS_MENU_PLAYER_DROPDOWN_TITLE"]);
	
	-- Initialise the dropdown using blizzard's standard functionset.
	UIDropDownMenu_Initialize(dropdown, ChoosePlayer_DropDown_Refresh);
	UIDropDownMenu_SetText(dropdown, L["TEAM_MENU_MEMBER_DROPDOWN_EMPTY_TEXT"]);
end

local function ChooseAlias_DropDown_OnClick(dropdownButton, alias)

	local name = dropdownButton.value;
	local dropdown = UIDROPDOWNMENU_OPEN_MENU;
	UIDropDownMenu_SetText(dropdown, dropdownButton.value);
	
	ALSpec_OptionsNameAliasesNameEditBox:SetText(name);
	ALSpec_OptionsNameAliasesAliasEditBox:SetText(alias);
	
end

local function ChooseAlias_DropDown_Refresh(dropdown)

	local currentName = ALSpec_OptionsNameAliasesNameEditBox:GetText();

	for playerName, alias in pairs(NameText.displayedNames) do
		
		info.text = playerName;
		info.value = playerName;
		info.func = ChooseAlias_DropDown_OnClick;
		info.arg1 = alias;
		info.colorCode = nil;		
		
		if ( currentName == info.value ) then
			UIDropDownMenu_SetText(dropdown, info.text);
			info.checked = true;
		else
			info.checked = nil;
		end	

		UIDropDownMenu_AddButton(info);
	end
end

local function ChooseAlias_DropDown_Initialise(dropdown)

	local prefix = dropdown:GetName();
	
	local title = _G[prefix.."Title"];
	
	-- Set dropdown title
	title:SetText(L["NAME_ALIAS_MENU_ALIAS_DROPDOWN_TITLE"]);
	
	-- Initialise the dropdown using blizzard's standard functionset.
	UIDropDownMenu_Initialize(dropdown, ChooseAlias_DropDown_Refresh);
	UIDropDownMenu_SetText(dropdown, L["TEAM_MENU_MEMBER_DROPDOWN_EMPTY_TEXT"]);
	

end

function Button_AddAlias()
	
	local currentName = ALSpec_OptionsNameAliasesNameEditBox:GetText();
	local currentAlias = ALSpec_OptionsNameAliasesAliasEditBox:GetText();

	if ( currentName and currentName ~= "" and currentAlias and currentAlias ~= "" ) then
		aliasDB[currentName] = currentAlias;
		NameText:SetNameAlias(currentName, currentAlias);
		
		ALSpec_OptionsNameAliases:UpdateAllUnitFrameNames();
		UIDropDownMenu_SetText(ALSpec_OptionsNameAliasesChooseAliasDropDown, currentName);
	end
	
end

function Button_RemoveAlias()
	
	local currentName = ALSpec_OptionsNameAliasesNameEditBox:GetText();

	if ( currentName and currentName ~= "" ) then
		aliasDB[currentName] = nil;
		NameText:DeleteNameAlias(currentName);
		
		ALSpec_OptionsNameAliasesNameEditBox:SetText("");
		ALSpec_OptionsNameAliasesAliasEditBox:SetText("");

		ALSpec_OptionsNameAliases:UpdateAllUnitFrameNames();
		UIDropDownMenu_SetText(ALSpec_OptionsNameAliasesChooseAliasDropDown, "");
	end
	
end

function Button_ResetAllAliases()
	for name, alias in pairs(aliasDB) do
		NameText:DeleteNameAlias(name);
		aliasDB[name] = nil;
	end

	ALSpec_OptionsNameAliasesNameEditBox:SetText("");
	ALSpec_OptionsNameAliasesAliasEditBox:SetText("");
	UIDropDownMenu_SetText(ALSpec_OptionsNameAliasesChooseAliasDropDown, "");
	ALSpec_OptionsNameAliases:UpdateAllUnitFrameNames();
end

function Button_ImportAliases()
	local import = ALSpec_OptionsNameAliasesScrollFrameImportExportEditBox:GetText();
	
	if ( string.find(import, "^(aliasDB =)") ) then
		local returnTable = ImportExport:LuaDataToTable(import);
		for name, alias in pairs(returnTable.aliasDB) do
			aliasDB[name] = alias;
			NameText:SetNameAlias(name, alias);
		end
	else
		ArenaLiveCore:Message(L["NAME_ALIAS_ERROR_WRONG_INPUT"], "error");
	end
	ALSpec_OptionsNameAliasesScrollFrameImportExportEditBox:SetText("");
	ALSpec_OptionsNameAliasesScrollFrameImportExportEditBox:SetCursorPosition(0);
end

function Button_ExportAliases()
	ALSpec_OptionsNameAliasesScrollFrameImportExportEditBox:SetText("aliasDB = " ..ImportExport:TableToLuaData(aliasDB));
	ALSpec_OptionsNameAliasesScrollFrameImportExportEditBox:SetFocus();
	ALSpec_OptionsNameAliasesScrollFrameImportExportEditBox:HighlightText();
end

function ALSpec_OptionsNameAliases:UpdateAllUnitFrameNames()

	for key, frame in pairs(UnitFrame.UnitFrameTable) do
		if ( frame.handlerList.nameText ) then
			frame.nameText:Update();
		end
	end

end

function ALSpec_OptionsNameAliases:Initialise()
	
	aliasDB = ArenaLiveCore:GetDBEntry(addonName, "NameAliases");
	
	-- Add Name aliases to ArenaLiveCore:
	for name, alias in pairs(aliasDB) do
		NameText:SetNameAlias(name, alias);
	end
	
	ALSpec_OptionsNameAliases:UpdateAllUnitFrameNames()
	
	local prefix = self:GetName();
	
	self.name = L["NAME_ALIAS_PANEL_NAME"];
	self.parent = L["ADDON_PANEL_NAME"];
	InterfaceOptions_AddCategory(self); 
	
	-- Set Titles:
	_G[prefix.."Title"]:SetText(L["NAME_ALIAS_PANEL_TITLE"]);
	_G[prefix.."NameEditBoxTitle"]:SetText(L["NAME_ALIAS_MENU_NAME_EDITBOX_TITLE"]);
	_G[prefix.."AliasEditBoxTitle"]:SetText(L["NAME_ALIAS_MENU_ALIAS_EDITBOX_TITLE"]);
	
	-- Initialise Option Parts:
	ChooseAlias_DropDown_Initialise(ALSpec_OptionsNameAliasesChooseAliasDropDown);
	ChoosePlayer_DropDown_Initialise(ALSpec_OptionsNameAliasesChoosePlayerDropDown);
	
	ArenaLiveOptions:InitialiseButton(ALSpec_OptionsNameAliasesAddButton, addonName, nil, Button_AddAlias, L["NAME_ALIAS_ADD_ALIAS_BUTTON"]);
	ArenaLiveOptions:InitialiseButton(ALSpec_OptionsNameAliasesDeleteButton, addonName, nil, Button_RemoveAlias, L["NAME_ALIAS_DELETE_ALIAS_BUTTON"]);
	ArenaLiveOptions:InitialiseButton(ALSpec_OptionsNameAliasesResetButton, addonName, nil, Button_ResetAllAliases, L["NAME_ALIAS_RESET_ALIAS_BUTTON"]);
	ArenaLiveOptions:InitialiseButton(ALSpec_OptionsNameAliasesScrollFrameImportButton, addonName, nil, Button_ImportAliases, L["NAME_ALIAS_IMPORT_BUTTON_TEXT"]);
	ArenaLiveOptions:InitialiseButton(ALSpec_OptionsNameAliasesScrollFrameExportButton, addonName, nil, Button_ExportAliases, L["NAME_ALIAS_EXPORT_BUTTON_TEXT"]);
end