local addonName = ...;

local function OnShow(self)

	local name = ArenaLiveSpectator:GetUnitName("targettarget");

	if ( name ) then
		if ( ArenaLiveSpectator.UnitsByNameTable[name] ) then
			self:SetUnit(ArenaLiveSpectator.UnitsByNameTable[name]);
		elseif ( self.unit ~= "targettarget" ) then
			self:SetUnit("targettarget");
		else
			self:SetUnitGUID("targettarget");
		end
	end
	
	self:Update();
	
	-- Events are not available for targettarget.
	if ( self.unit == "targettarget" ) then
		self.auraFrame:Reset();
	end
end

local function OnUpdate(self, elapsed)
	if ( self.unit ) then
		
		local guid = UnitGUID("targettarget");
		
		if ( guid ~= self.guid ) then
			local name = ArenaLiveSpectator:GetUnitName("targettarget");

			if ( ArenaLiveSpectator.UnitsByNameTable[name] ) then
				self:SetUnit(ArenaLiveSpectator.UnitsByNameTable[name]);
			elseif ( self.unit ~= "targettarget" ) then
				self:SetUnit("targettarget");
			else
				self:SetUnitGUID("targettarget");
			end
			
			self:Update();
			
			-- Events are not available for targettarget.
			if ( self.unit == "targettarget" ) then
				self.auraFrame:Reset();
			end
		end
	end
end

function ArenaLiveSpectator:InitialiseTargetFrame(frame)
	local prefix = frame:GetName();
	
	ArenaLiveCore:AddFrame(frame, "UnitFrame", addonName, "TargetFrame", menufunc, false, false);
	frame:SetAttribute("alframelock", true);
	ArenaLiveCore:AddFrame(_G[prefix.."Name"], "NameText", frame);
	ArenaLiveCore:AddFrame(_G[prefix.."Portrait"], "Portrait", _G[prefix.."PortraitTexture"], _G[prefix.."Portrait3D"], frame);
	ArenaLiveCore:AddFrame(_G[prefix.."HealthBar"], "HealthBar", frame, true);
	ArenaLiveCore:AddFrame (_G[prefix.."HealthBarText"], "StatusBarText", "HealthBarText", nil, nil, true, frame);
	ArenaLiveCore:AddFrame(_G[prefix.."PowerBar"], "PowerBar", frame, true);
	ArenaLiveCore:AddFrame (_G[prefix.."PowerBarText"], "StatusBarText", "PowerBarText", nil, true, nil, frame);
	ArenaLiveCore:AddFrame(_G[prefix.."Icon1"], "Icon", _G[prefix.."Icon1Texture"], _G[prefix.."Icon1Cooldown"], _G[prefix.."Icon1CooldownText"], frame);
	ArenaLiveCore:AddFrame(_G[prefix.."Icon2"], "Icon", _G[prefix.."Icon2Texture"], _G[prefix.."Icon2Cooldown"], _G[prefix.."Icon2CooldownText"], frame);
	ArenaLiveCore:AddFrame(_G[prefix.."PortraitOverlay"], "CCIndicator", _G[prefix.."PortraitOverlayIcon"], _G[prefix.."PortraitOverlayCooldown"], _G[prefix.."PortraitOverlayCooldownText"], frame);
	ArenaLiveCore:AddFrame (_G[prefix.."AuraFrame"], "Aura", _G[prefix.."AuraFrameBuffFrame"], _G[prefix.."AuraFrameDebuffFrame"], "ArenaLive_BuffTemplate", "ArenaLive_DebuffTemplate", frame);
	ArenaLiveCore:AddFrame(_G[prefix.."AbsorbBar"], "AbsorbBar", _G[prefix.."AbsorbBarOverlay"], 32, _G[prefix.."AbsorbBarFullHPIndicator"], frame);
	ArenaLiveCore:AddFrame(_G[prefix.."CastBar"], "CastBar", _G[prefix.."CastBarBorder"], _G[prefix.."CastBarShieldGlow"], _G[prefix.."CastBarIcon"], _G[prefix.."CastBarText"], _G[prefix.."CastBarAnimationGroup"], _G[prefix.."CastBarAnimationGroupFadeOut"], true, true, frame);
	ArenaLiveCore:AddFrame(_G[prefix.."CastHistory"], "CastHistory", "ArenaLive_CastHistoryIconTemplate", frame);
	ArenaLiveCore:AddFrame(_G[prefix.."SpiritHealerFrame"], "SpiritHealer", _G[prefix.."SpiritHealerFrameTexture"], _G[prefix.."SpiritHealerFrameFlash"], 5, frame);
end

function ArenaLiveSpectator:InitialiseTargetOfTargetFrame(frame)
	local prefix = frame:GetName();
	
	ArenaLiveCore:AddFrame(frame, "UnitFrame", addonName, "TargetOfTargetFrame", menufunc, false, false);
	frame:SetAttribute("alframelock", true);
	ArenaLiveCore:AddFrame(_G[prefix.."Name"], "NameText", frame);
	ArenaLiveCore:AddFrame(_G[prefix.."Portrait"], "Portrait", _G[prefix.."PortraitTexture"], _G[prefix.."Portrait3D"], frame);
	ArenaLiveCore:AddFrame(_G[prefix.."HealthBar"], "HealthBar", frame, true);
	ArenaLiveCore:AddFrame (_G[prefix.."HealthBarText"], "StatusBarText", "HealthBarText", nil, nil, true, frame);
	ArenaLiveCore:AddFrame(_G[prefix.."PowerBar"], "PowerBar", frame, true);
	ArenaLiveCore:AddFrame (_G[prefix.."PowerBarText"], "StatusBarText", "PowerBarText", nil, true, nil, frame);
	ArenaLiveCore:AddFrame(_G[prefix.."Icon1"], "Icon", _G[prefix.."Icon1Texture"], _G[prefix.."Icon1Cooldown"], _G[prefix.."Icon1CooldownText"], frame);
	ArenaLiveCore:AddFrame(_G[prefix.."Icon2"], "Icon", _G[prefix.."Icon2Texture"], _G[prefix.."Icon2Cooldown"], _G[prefix.."Icon2CooldownText"], frame);
	ArenaLiveCore:AddFrame(_G[prefix.."PortraitOverlay"], "CCIndicator", _G[prefix.."PortraitOverlayIcon"], _G[prefix.."PortraitOverlayCooldown"], _G[prefix.."PortraitOverlayCooldownText"], frame);
	ArenaLiveCore:AddFrame (_G[prefix.."AuraFrame"], "Aura", _G[prefix.."AuraFrameBuffFrame"], _G[prefix.."AuraFrameDebuffFrame"], "ArenaLive_BuffTemplate", "ArenaLive_DebuffTemplate", frame);
	ArenaLiveCore:AddFrame(_G[prefix.."AbsorbBar"], "AbsorbBar", _G[prefix.."AbsorbBarOverlay"], 32, _G[prefix.."AbsorbBarFullHPIndicator"], frame);
	ArenaLiveCore:AddFrame(_G[prefix.."CastBar"], "CastBar", _G[prefix.."CastBarBorder"], _G[prefix.."CastBarShieldGlow"], _G[prefix.."CastBarIcon"], _G[prefix.."CastBarText"], _G[prefix.."CastBarAnimationGroup"], _G[prefix.."CastBarAnimationGroupFadeOut"], true, true, frame);
	ArenaLiveCore:AddFrame(_G[prefix.."CastHistory"], "CastHistory", "ArenaLive_CastHistoryIconTemplate", frame);
	ArenaLiveCore:AddFrame(_G[prefix.."SpiritHealerFrame"], "SpiritHealer", _G[prefix.."SpiritHealerFrameTexture"], _G[prefix.."SpiritHealerFrameFlash"], 5, frame);
	frame:SetScript("OnUpdate", OnUpdate);
	frame:SetScript("OnShow", OnShow);
end